@@ -1395,6 +1395,9 @@ int msLayerGetFeatureStyle(mapObj *map, layerObj *layer, classObj *c,
     }
 
     msUpdateStyleFromString(c->styles[0], stylestring);
+    double geo_cellsize = msGetGeoCellSize(map);
+    msUpdateClassScaleFactor(geo_cellsize, map, layer, c);
+
     if (c->styles[0]->symbolname) {
       if ((c->styles[0]->symbol = msGetSymbolIndex(
                &(map->symbolset), c->styles[0]->symbolname, MS_TRUE)) == -1) {
@@ -1412,6 +1415,8 @@ int msLayerGetFeatureStyle(mapObj *map, layerObj *layer, classObj *c,
       c->layer = layer;
     }
     msUpdateClassFromString(c, stylestring);
+    double geo_cellsize = msGetGeoCellSize(map);
+    msUpdateClassScaleFactor(geo_cellsize, map, layer, c);
   } else if (strncasecmp(stylestring, "pen", 3) == 0 ||
              strncasecmp(stylestring, "brush", 5) == 0 ||
              strncasecmp(stylestring, "symbol", 6) == 0 ||
